@@ -73,35 +73,72 @@ def mseed_predictor(input_dir='downloads_mseeds',
               gpu_limit=None): 
     
  
-    r"""
+    """
     
     To perform fast detection directly on mseed data.
     This version does not allow uncertainty estimation or writing the probabilities out. 
 
-    Args:        
-        input_dir (str, optional): Directory name containing hdf5 and csv files-preprocessed data. Defaults to None.         
-        input_model (str, optional): Path to a trained model. Defaults to None.           
-        stations_json (str, optional): Path to a JSON file containing station information.Defaults to None.           
-        output_dir (str, optional): Output directory. Defaults to None.              
-        detection_threshold (float, optional): A value in which the detection probabilities above it will be considered as an event. Defaults to 0.3.                
-        P_threshold (float, optional): A value which the P probabilities above it will be considered as P arrival. Defaults to 0.1.            
-        S_threshold (float, optional): A value which the S probabilities above it will be considered as S arrival. Defaults to 0.1.               
-        number_of_plots (int, optional): The number of plots for detected events outputed for each station data. Defaults to 10.        
-        plot_mode (str, optional): The type of plots: 'time': only time series or 'time_frequency': time and spectrograms. Defaults to 'time'.             
-        loss_weights (list, [optional): Loss weights for detection, P picking, and S picking respectively. Defaults to [0.03, 0.40, 0.58].               
-        loss_types (list, optional): Loss types for detection, P picking, and S picking respectively. Defaults to ['binary_crossentropy', 'binary_crossentropy', 'binary_crossentropy']        
-        normalization_mode (str, optional): Mode of normalization for data preprocessing, 'max': maximum amplitude among three components, 'std': standard deviation. Defaults to 'std'           
-        batch_size: (int, optional): Batch size. Defaults to 500.           
-        overlap (float, optional): If set, detection, and picking are performed in overlapping windows. Defaults to 0.3.           
-        gpuid (int, optional): Id of GPU used for the prediction. If using CPU set to None. Defaults to None.           
-        gpu_limit (int, optional): Set the maximum percentage of memory usage for the GPU. Defaults to None.
+    Parameters
+    ----------
+    input_dir: str, default=None
+        Directory name containing hdf5 and csv files-preprocessed data.
 
+    input_model: str, default=None
+        Path to a trained model.
 
-    Returns:
-        ./output_dir/STATION_OUTPUT/X_prediction_results.csv: A table containing all the detection, and picking results. Duplicated events are already removed.      
-        ./output_dir/STATION_OUTPUT/X_report.txt: A summary of the parameters used for prediction and performance.
-        ./output_dir/STATION_OUTPUT/figures: A folder containing plots detected events and picked arrival times. 
-        ./time_tracks.pkl: A file containing the time track of the continous data and its type.
+    stations_json: str, default=None
+        Path to a JSON file containing station information.       
+         
+    output_dir: str, default=None
+        Output directory that will be generated. 
+
+    detection_threshold : float, default=0.3
+        A value in which the detection probabilities above it will be considered as an event.
+          
+    P_threshold: float, default=0.1
+        A value which the P probabilities above it will be considered as P arrival.
+
+    S_threshold: float, default=0.1
+        A value which the S probabilities above it will be considered as S arrival.
+               
+    number_of_plots: float, default=10
+        The number of plots for detected events outputed for each station data.
+
+    plot_mode: str, default='time'
+        The type of plots: 'time': only time series or 'time_frequency', time and spectrograms.
+          
+    loss_weights: list, default=[0.03, 0.40, 0.58]
+        Loss weights for detection, P picking, and S picking respectively.
+             
+    loss_types: list, default=['binary_crossentropy', 'binary_crossentropy', 'binary_crossentropy'] 
+        Loss types for detection, P picking, and S picking respectively.
+ 
+    normalization_mode : str, default='std' 
+        Mode of normalization for data preprocessing, 'max', maximum amplitude among three components, 'std', standard deviation.
+           
+    batch_size: int, default=500 
+        Batch size. This wont affect the speed much but can affect the performance. A value beteen 200 to 1000 is recommanded.
+
+    overlap: float, default=0.3
+        If set, detection, and picking are performed in overlapping windows.
+
+    gpuid: int, default=None
+        Id of GPU used for the prediction. If using CPU set to None.
+         
+    gpu_limit: int, default=None
+        Set the maximum percentage of memory usage for the GPU.
+          
+
+    Returns
+    -------- 
+    ./output_dir/STATION_OUTPUT/X_prediction_results.csv: A table containing all the detection, and picking results. Duplicated events are already removed.      
+    
+    ./output_dir/STATION_OUTPUT/X_report.txt: A summary of the parameters used for prediction and performance.
+    
+    ./output_dir/STATION_OUTPUT/figures: A folder containing plots detected events and picked arrival times. 
+    
+    ./time_tracks.pkl: A file containing the time track of the continous data and its type.
+    
         
     """      
     
@@ -297,6 +334,7 @@ def mseed_predictor(input_dir='downloads_mseeds',
         
         
 def _mseed2nparry(args, matching, time_slots, comp_types, st_name):
+    ' read miniseed files and from a list of string names and returns 3 dictionaries of numpy arrays, meta data, and time slice info'
     
     json_file = open(args['stations_json'])
     stations_ = json.load(json_file)
@@ -388,7 +426,38 @@ def _mseed2nparry(args, matching, time_slots, comp_types, st_name):
 
 
 class PreLoadGeneratorTest(keras.utils.Sequence):
- 
+    
+    """ 
+    
+    Keras generator with preprocessing. For testing. Pre-load version.
+    
+    Parameters
+    ----------
+    list_IDsx: str
+        List of trace names.
+            
+    file_name: str
+        Path to the input hdf5 file.
+            
+    dim: tuple
+        Dimension of input traces. 
+           
+    batch_size: int, default=32.
+        Batch size.
+            
+    n_channels: int, default=3.
+        Number of channels.
+            
+    norm_mode: str, default=max
+        The mode of normalization, 'max' or 'std'                
+            
+    Returns:
+    --------        
+    Batches of two dictionaries: {'input': X}: pre-processed waveform as input {'detector': y1, 'picker_P': y2, 'picker_S': y3}: outputs including three separate numpy arrays as labels for detection, P, and S respectively.
+    
+    
+    """  
+    
     def __init__(self, 
                  list_IDs, 
                  inp_data, 
@@ -561,7 +630,7 @@ def _output_writter_prediction(meta, predict_writer, csvPr, matches, snr, detect
             
 
 
-def _get_snr(data, pat, window = 200):
+def _get_snr(data, pat, window=200):
     
     """ 
     
@@ -575,7 +644,7 @@ def _get_snr(data, pat, window = 200):
     pat: positive integer
         Sample point where a specific phase arrives. 
         
-    window: positive integer
+    window: positive integer, default=200
         The length of the window for calculating the SNR (in the sample).         
         
     Returns
@@ -609,8 +678,7 @@ def _get_snr(data, pat, window = 200):
 
 
 
-def _detect_peaks(x, mph=None, mpd=1, threshold=0, edge='rising',
-                 kpsh=False, valley=False):
+def _detect_peaks(x, mph=None, mpd=1, threshold=0, edge='rising', kpsh=False, valley=False):
 
     """
     
@@ -621,32 +689,28 @@ def _detect_peaks(x, mph=None, mpd=1, threshold=0, edge='rising',
     x : 1D array_like
         data.
         
-    mph : {None, number}, optional (default = None)
+    mph : {None, number}, default=None
         detect peaks that are greater than minimum peak height.
         
-    mpd: positive integer, optional (default = 1)
-        detect peaks that are at least separated by minimum peak distance (in
-        the number of data).
+    mpd : int, default=1
+        detect peaks that are at least separated by minimum peak distance (in number of data).
         
-    threshold : positive number, optional (default = 0)
-        detect peaks (valleys) that are greater (smaller) than `threshold`
-        in relation to their immediate neighbors.
+    threshold : int, default=0
+        detect peaks (valleys) that are greater (smaller) than `threshold in relation to their immediate neighbors.
         
-    edge : {None, 'rising', 'falling', 'both'}, optional (default = 'rising')
-        for a flat peak, keep only the rising edge ('rising'), only the
-        falling edge ('falling'), both edges ('both'), or don't detect a
-        flat peak (None).
+    edge : str, default=rising
+        for a flat peak, keep only the rising edge ('rising'), only the falling edge ('falling'), both edges ('both'), or don't detect a flat peak (None).
         
-    kph : bool, optional (default = False)
-        keep peaks with the same height even if they are closer than `mpd`.
+    kpsh : bool, default=False
+        keep peaks with same height even if they are closer than `mpd`.
         
-    valley : bool, optional (default = False)
+    valley : bool, default=False
         if True (1), detect valleys (local minima) instead of peaks.
 
     Returns
     -------
     ind : 1D array_like
-        indices of the peaks in `x`.
+        indeces of the peaks in `x`.
 
     Modified from 
     ----------
@@ -719,40 +783,31 @@ def _picker(args, yh1, yh2, yh3):
 
     Parameters
     ----------
-    args : object
-        A argparse object containing all of the input parameters.     
+    args : dic
+        A dictionary containing all of the input parameters.  
+        
     yh1 : 1D array
         Detection probabilities. 
+        
     yh2 : 1D array
-        P arrival probabilities.         
+        P arrival probabilities.  
+        
     yh3 : 1D array
-        S arrival probabilities.       
+        S arrival probabilities. 
+        
    
     Returns
     -------    
-    matches: dic
-        It contains the information for the detected and picked event.            
+    matches : dic
+        Contains the information for the detected and picked event.            
+        
+    matches : dic
+        {detection statr-time:[ detection end-time, detection probability, detectin uncertainty, P arrival, P probabiliy, P uncertainty, S arrival,  S probability, S uncertainty]}
         
-        matches --> {detection statr-time:[ detection end-time,
-                                           detection probability,
-                                           detectin uncertainty,
-                                           P arrival, 
-                                           P probabiliy, 
-                                           P uncertainty,
-                                           S arrival, 
-                                           S probability, 
-                                           S uncertainty
-                                           
-                                           ]}
-    pick_errors : dic                
-        pick_errors -->  {detection statr-time:[ P_ground_truth - P_pick,   
-                                                 S_ground_truth - S_pick,
-                                                ]}
     yh3 : 1D array             
-        yh3 --> normalized S_probability
-                              
+        normalized S_probability                              
                 
-    """               
+    """                
              
     detection = trigger_onset(yh1, args['detection_threshold'], args['detection_threshold'])
     pp_arr = _detect_peaks(yh2, mph=args['P_threshold'], mpd=1)
@@ -873,7 +928,10 @@ def _picker(args, yh1, yh2, yh3):
     return matches, pick_errors, yh3
 
 
+
 def _resampling(st):
+    'perform resampling on Obspy stream objects'
+    
     need_resampling = [tr for tr in st if tr.stats.sampling_rate != 100.0]
     if len(need_resampling) > 0:
        # print('resampling ...', flush=True)    
@@ -888,7 +946,28 @@ def _resampling(st):
             st.append(tr) 
     return st 
 
-def _normalize(data, mode = 'max'):          
+
+
+def _normalize(data, mode = 'max'):  
+    """ 
+    
+    Normalize 3D arrays.
+    
+    Parameters
+    ----------
+    data : 3D numpy array
+        3 component traces. 
+        
+    mode : str, default='std'
+        Mode of normalization. 'max' or 'std'     
+        
+    Returns
+    -------  
+    data : 3D numpy array
+        normalized data. 
+            
+    """  
+       
     data -= np.mean(data, axis=0, keepdims=True)
     if mode == 'max':
         max_data = np.max(data, axis=0, keepdims=True)
@@ -906,13 +985,11 @@ def _normalize(data, mode = 'max'):
 
 
 
-
-
 def _plotter_prediction(data, args, save_figs, yh1, yh2, yh3, evi, matches):
 
     """ 
     
-    Generates plots.
+    Generates plots of detected events with the prediction probabilities and arrival picks.
 
     Parameters
     ----------
@@ -939,7 +1016,7 @@ def _plotter_prediction(data, args, save_figs, yh1, yh2, yh3, evi, matches):
 
     matches: dic
         Contains the information for the detected and picked event. 
-           
+                  
         
     """  
 
@@ -1277,4 +1354,5 @@ def _plotter_prediction(data, args, save_figs, yh1, yh2, yh3, evi, matches):
         fig.savefig(os.path.join(save_figs, str(evi)+'.png')) 
         plt.close(fig)
         plt.clf()
+        
         
\ No newline at end of file
