@@ -65,58 +65,133 @@ def trainer(input_hdf5=None,
             gpu_limit=None,
             use_multiprocessing=True):
         
-    r"""
+    """
     
     Generate a model and train it.  
+    
+    Parameters
+    ----------
+    input_hdf5: str, default=None
+        Path to an hdf5 file containing only one class of data with NumPy arrays containing 3 component waveforms each 1 min long.
 
-    Args:        
-        input_hdf5 (str, optional): Path to an hdf5 file containing only one class of "data" with NumPy arrays containing 3 component waveforms each 1 min long. Defaults to None.          
-        input_csv (str, optional): Path to a CSV file with one column (trace_name) listing the name of all datasets in the hdf5 file. Defaults to None.                  
-        output_name (str, optional): Output directory. Defaults to None.   
-        input_dimention (int, optional): Loss types for detection, P picking, and S picking respectively. Defaults to (6000, 3).        
-        cnn_blocks (int, optional): The number of residual blocks of convolutional layers. Defaults to 5.        
-        lstm_blocks (int, optional): The number of residual blocks of BiLSTM layers. Defaults to 2.        
-        padding (str, optional): Padding type. Defaults to 'same'.        
-        activation (str, optional): Activation function used in the hidden layers. Defaults to 'relu'.        
-        drop_rate (float, optional): Dropout value. Defaults to 0.1.        
-        shuffle (bool, optional): To shuffle the list prior to the training. Defaults to True.        
-        label_type (str, optional): Labeling type. 'gaussian', 'triangle', or 'box'. Defaults to 'triangle'.        
-        normalization_mode (str, optional): Mode of normalization for data preprocessing, 'max': maximum amplitude among three components, 'std': standard deviation. 'gaussian', 'triangle', or 'box'. Defaults to 'std'.        
-        laugmentation (bool, optional): If True, data will be augmented simultaneously during the training. 'gaussian', 'triangle', or 'box'. Defaults to True.        
-        add_event_r (float, optional): Rate of augmentation for adding a secondary event randomly into the empty part of a trace. Defaults to 0.6.        
-        shift_event_r (float, optional): Rate of augmentation for randomly shifting the event within a trace.. Defaults to 0.99.        
-        add_noise_r (float, optional): Rate of augmentation for adding Gaussian noise with different SNR into a trace. Defaults to 0.3.        
-        drop_channel_r (float, optional): Rate of augmentation for randomly dropping one of the channels. Defaults to 0.4.        
-        add_gap_r (float, optional): Add an interval with zeros into the waveform representing filled gaps. Defaults to 0.2.        
-        scale_amplitude_r (float, optional): Rate of augmentation for randomly scaling the trace. Defaults to None.        
-        pre_emphasis (bool, optional): If True, waveforms will be pre-emphasized. Defaults to False.        
-        loss_weights (list, [optional): Loss weights for detection, P picking, and S picking respectively. Defaults to [0.03, 0.40, 0.58].               
-        loss_types (list, optional): Loss types for detection, P picking, and S picking respectively. Defaults to ['binary_crossentropy', 'binary_crossentropy', 'binary_crossentropy']        
-        train_valid_test_split (list, optional): Precentage of data split into the training, validation, and test sets respectively. Defaults to [0.85, 0.05, 0.10].           
-        mode: (str, optional): Mode of running. 'generator', or 'preload'. Defaults to 'generator'.           
-        batch_size: (int, optional): Batch size. Defaults to 200.           
-        epochs: (int, optional): The number of epochs. Defaults to 200.           
-        monitor: (int, optional): The measure used for monitoring. Defaults to 'val_loss'.           
-        patience: (int, optional): The number of epochs without any improvement in the monitoring measure to automatically stop the training. Defaults to 12.           
-        multi_gpu: (bool, optional): If True, multiple GPUs will be used for the training. Defaults to False.           
-        number_of_gpus: (int, optional): Number of GPUs uses for multi-GPU training. Defaults to 4.           
-        gpuid (int, optional): Id of GPU used for the prediction. If using CPU set to None. Defaults to None.           
-        gpu_limit (float, optional): Set the maximum percentage of memory usage for the GPU. Defaults to None.
-        use_multiprocessing (bool optional): If True, multiple CPUs will be used for the preprocessing of data even when GPU is used for the prediction. Defaults to True.
+    input_csv: str, default=None
+        Path to a CSV file with one column (trace_name) listing the name of all datasets in the hdf5 file.
 
-    Returns:
-        ./output_name/models/output_name_???.h5: This is where all good models will be saved.      
-        ./output_name/final_model.h5: This is the full model for the last epoch.
-        ./output_name/model_weights.h5: These are the weights for the last model.
-        ./output_name/history.npy: Training history.
-        ./output_name/X_report.txt: A summary of the parameters used for prediction and performance.
-        ./output_name/test.npy: A number list containing the trace names for the test set.
-        ./output_name/X_learning_curve_f1.png: The learning curve of Fi-scores.
-        ./output_name/X_learning_curve_loss.png: The learning curve of loss.
+    output_name: str, default=None
+        Output directory.
+        
+    input_dimention: tuple, default=(6000, 3)
+        OLoss types for detection, P picking, and S picking respectively. 
+        
+    cnn_blocks: int, default=5
+        The number of residual blocks of convolutional layers.
+        
+    lstm_blocks: int, default=2
+        The number of residual blocks of BiLSTM layers.
+        
+    padding: str, default='same'
+        Padding type.
+        
+    activation: str, default='relu'
+        Activation function used in the hidden layers.
 
-    Notes:
-        'generator' mode is memory efficient and more suitable for machines with fast disks. 
-        'pre_load' mode is faster but requires more memory and it comes with only box labeling.
+    drop_rate: float, default=0.1
+        Dropout value.
+
+    shuffle: bool, default=True
+        To shuffle the list prior to the training.
+
+    label_type: str, default='triangle'
+        Labeling type. 'gaussian', 'triangle', or 'box'. 
+
+    normalization_mode: str, default='std'
+        Mode of normalization for data preprocessing, 'max': maximum amplitude among three components, 'std', standard deviation. 
+
+    augmentation: bool, default=True
+        If True, data will be augmented simultaneously during the training.
+
+    add_event_r: float, default=0.6
+        Rate of augmentation for adding a secondary event randomly into the empty part of a trace.
+
+    shift_event_r: float, default=0.99
+        Rate of augmentation for randomly shifting the event within a trace.
+      
+    add_noise_r: float, defaults=0.3 
+        Rate of augmentation for adding Gaussian noise with different SNR into a trace.       
+        
+    drop_channel_r: float, defaults=0.4 
+        Rate of augmentation for randomly dropping one of the channels.
+
+    add_gap_r: float, defaults=0.2 
+        Add an interval with zeros into the waveform representing filled gaps.       
+        
+    scale_amplitude_r: float, defaults=None
+        Rate of augmentation for randomly scaling the trace. 
+              
+    pre_emphasis: bool, defaults=False
+        If True, waveforms will be pre-emphasized. Defaults to False.  
+        
+    loss_weights: list, defaults=[0.03, 0.40, 0.58]
+        Loss weights for detection, P picking, and S picking respectively.
+              
+    loss_types: list, defaults=['binary_crossentropy', 'binary_crossentropy', 'binary_crossentropy'] 
+        Loss types for detection, P picking, and S picking respectively.  
+        
+    train_valid_test_split: list, defaults=[0.85, 0.05, 0.10]
+        Precentage of data split into the training, validation, and test sets respectively. 
+          
+    mode: str, defaults='generator'
+        Mode of running. 'generator', or 'preload'. 
+         
+    batch_size: int, default=200
+        Batch size.
+          
+    epochs: int, default=200
+        The number of epochs.
+          
+    monitor: int, default='val_loss'
+        The measure used for monitoring.
+           
+    patience: int, default=12
+        The number of epochs without any improvement in the monitoring measure to automatically stop the training.          
+        
+    multi_gpu: bool, default=False
+        If True, multiple GPUs will be used for the training. 
+           
+    number_of_gpus: int, default=4
+        Number of GPUs uses for multi-GPU training.
+           
+    gpuid: int, default=None
+        Id of GPU used for the prediction. If using CPU set to None. 
+         
+    gpu_limit: float, default=None
+        Set the maximum percentage of memory usage for the GPU.
+        
+    use_multiprocessing: bool, default=True
+        If True, multiple CPUs will be used for the preprocessing of data even when GPU is used for the prediction. 
+
+    Returns
+    -------- 
+    output_name/models/output_name_.h5: This is where all good models will be saved.  
+    
+    output_name/final_model.h5: This is the full model for the last epoch.
+    
+    output_name/model_weights.h5: These are the weights for the last model.
+    
+    output_name/history.npy: Training history.
+    
+    output_name/X_report.txt: A summary of the parameters used for prediction and performance.
+    
+    output_name/test.npy: A number list containing the trace names for the test set.
+    
+    output_name/X_learning_curve_f1.png: The learning curve of Fi-scores.
+    
+    output_name/X_learning_curve_loss.png: The learning curve of loss.
+
+    Notes
+    -------- 
+    'generator' mode is memory efficient and more suitable for machines with fast disks. 
+    'pre_load' mode is faster but requires more memory and it comes with only box labeling.
         
     """     
 
@@ -169,21 +244,28 @@ def trainer(input_hdf5=None,
 
         Returns
         -------
-        history : dic
-            Training history.     
-        model : 
-            Trained model.  
-        start_training : datetime
+        history: dic
+            Training history.  
+            
+        model: 
+            Trained model.
+            
+        start_training: datetime
             Training start time. 
-        end_training : datetime
-            Training end time.             
-        save_dir : str
+            
+        end_training: datetime
+            Training end time. 
+            
+        save_dir: str
             Path to the output directory. 
-        save_models : str
-            Path to the folder for saveing the models.        
-        training size : int
-            Number of training samples.    
-        validation size : int
+            
+        save_models: str
+            Path to the folder for saveing the models.  
+            
+        training size: int
+            Number of training samples.
+            
+        validation size: int
             Number of validation samples.  
             
         """    
@@ -286,14 +368,15 @@ def _make_dir(output_name):
 
     Parameters
     ----------
-    output_name : str
+    output_name: str
         Name of the output directory.
                    
     Returns
     -------   
-    save_dir : str
+    save_dir: str
         Full path to the output directory.
-    save_models : str
+        
+    save_models: str
         Full path to the model directory. 
         
     """   
@@ -319,12 +402,12 @@ def _build_model(args):
 
     Parameters
     ----------
-    args : dic
+    args: dic
         A dictionary containing all of the input parameters. 
                
     Returns
     -------   
-    model : 
+    model: 
         Compiled model.
         
     """       
@@ -405,7 +488,7 @@ def _make_callback(args, save_models):
               
     Returns
     -------   
-    callbacks : obj
+    callbacks: obj
         List of callback objects. 
         
         
@@ -447,15 +530,15 @@ def _pre_loading(args, training, validation):
     training: str
         List of trace names for the training set. 
         
-    validation : str
+    validation: str
         List of trace names for the validation set. 
               
     Returns
     -------   
-    training_generator : obj
+    training_generator: obj
         Keras generator for the training set. 
         
-    validation_generator : obj
+    validation_generator: obj
         Keras generator for the validation set. 
         
         
@@ -523,46 +606,42 @@ def _document_training(history, model, start_training, end_training, save_dir, s
 
     Parameters
     ----------
-    history : dic
+    history: dic
         Training history.  
    
-    model : 
+    model: 
         Trained model.  
 
-    start_training : datetime
+    start_training: datetime
         Training start time. 
 
-    end_training : datetime
+    end_training: datetime
         Training end time.    
          
-    save_dir : str
+    save_dir: str
         Path to the output directory. 
 
-    save_models : str
+    save_models: str
         Path to the folder for saveing the models.  
       
-    training_size : int
+    training_size: int
         Number of training samples.    
 
-    validation_size : int
+    validation_size: int
         Number of validation samples. 
 
-    ar : object
-        A argparse object containing all of the input parameters. 
+    args: dic
+        A dictionary containing all of the input parameters. 
               
-    Generates
-    -------
-    ./output_name/history.npy  
-        Training history.    
+    Returns
+    -------- 
+    ./output_name/history.npy: Training history.    
 
-    ./output_name/X_report.txt
-        A summary of parameters used for the prediction and perfomance.
+    ./output_name/X_report.txt: A summary of parameters used for the prediction and perfomance.
 
-    ./output_name/X_learning_curve_f1.png
-        The learning curve of Fi-scores.         
+    ./output_name/X_learning_curve_f1.png: The learning curve of Fi-scores.         
 
-    ./output_name/X_learning_curve_loss.png
-        The learning curve of loss.  
+    ./output_name/X_learning_curve_loss.png: The learning curve of loss.  
         
         
     """   
