@@ -33,46 +33,45 @@ def run_associator(input_dir,
                    output_dir='.',
                    consider_combination=False):
     
-    r"""
+    """
     
     It performs a very simple association based on detection times on multiple stations.
     It works fine when you have a small and local network of seismic stations. 
 
-    Args:        
-        input_dir (str): Path to a dicrectory containing detection results. Defaults to None.
-        start_time (str): Start of a time period of interest in 'YYYY-MM-DD hh:mm:ss.f' format. Defaults to None.
-        end_time (str): End of a timeperiod of interest in 'YYYY-MM-DD hh:mm:ss.f' format. Defaults to None.
-        moving_window (int): The length of time window used for association in second. Defaults to 15.
-        pair_n (int): The minimum number of stations used for the association. Defaults to 2.
-        output_dir (str): Path to the directory to write the output file. Defaults to '.'.
-        consider_combination (bool): If True, it will write down all possible combinations of picked arrival times for each event. 
-           This will generate multiple events with the same ID, and you will need to remove those with poor solutions after location. This helps to remove the false positives from the associated event. Defaults to False.
-
-         
-        input_model (str): Path to a trained model. Defaults to None.           
-        stations_json (str): Path to a JSON file containing station information.Defaults to None.           
-        output_dir (str): Output directory. Defaults to None.              
-        detection_threshold (float): A value in which the detection probabilities above it will be considered as an event. Defaults to 0.3.                
-        P_threshold (float): A value which the P probabilities above it will be considered as P arrival. Defaults to 0.1.            
-        S_threshold (float): A value which the S probabilities above it will be considered as S arrival. Defaults to 0.1.               
-        number_of_plots (int): The number of plots for detected events outputed for each station data. Defaults to 10.        
-        plot_mode (str): The type of plots: 'time': only time series or 'time_frequency': time and spectrograms. Defaults to 'time'.             
-        loss_weights (list): Loss weights for detection, P picking, and S picking respectively. Defaults to [0.03, 0.40, 0.58].               
-        loss_types (list): Loss types for detection, P picking, and S picking respectively. Defaults to ['binary_crossentropy', 'binary_crossentropy', 'binary_crossentropy']        
-        normalization_mode (str): Mode of normalization for data preprocessing, 'max': maximum amplitude among three components, 'std': standard deviation. Defaults to 'std'           
-        batch_size: (int): Batch size. Defaults to 500.           
-        overlap (float): If set, detection, and picking are performed in overlapping windows. Defaults to 0.3.           
-        gpuid (int): Id of GPU used for the prediction. If using CPU set to None. Defaults to None.           
-        gpu_limit (int): Set the maximum percentage of memory usage for the GPU. Defaults to None.
+    Parameters
+    ----------
+    input_dir: str, default=None
+        Directory name containing hdf5 and csv files-preprocessed data.
+        
+    start_time: str, default=None
+        Start of a time period of interest in 'YYYY-MM-DD hh:mm:ss.f' format.
+        
+    end_time: str, default=None
+        End of a timeperiod of interest in 'YYYY-MM-DD hh:mm:ss.f' format. 
+        
+    moving_window: int, default=15
+        The length of time window used for association in second. 
+        
+    pair_n: int, default=2
+        The minimum number of stations used for the association. 
+        
+    output_dir: str, default='.'
+        Path to the directory to write the output file.
+        
+    consider_combination: bool, default=False
+        If True, it will write down all possible combinations of picked arrival times for each event. This will generate multiple events with the same ID, and you will need to remove those with poor solutions after location. This helps to remove the false positives from the associated event. 
 
 
-    Returns:
-        ./output_dir/Y2000.phs: Phase information for the associated events in hypoInverse format.     
-        ./output_dir/traceNmae_dic.json: A dictionary where the trace name for all the detections associated to an event are listed. This can be used later to access the traces for calculating the cross-correlations during the relocation process. 
+    Returns
+    ----------        
+    output_dir/Y2000.phs: Phase information for the associated events in hypoInverse format.     
+    
+    output_dir/traceNmae_dic.json: A dictionary where the trace name for all the detections associated to an event are listed. This can be used later to access the traces for calculating the cross-correlations during the relocation process. 
         
         
-    Warning:
-        Unlike the other modules, this function does not create the ouput directory. So if the given path does not exist will give an error. 
+    Warning
+    ----------        
+    Unlike the other modules, this function does not create the ouput directory. So if the given path does not exist will give an error. 
         
     """   
    
@@ -237,16 +236,9 @@ def _pick_database_maker(conn, cur, input_file):
 
 
 def _decimalDegrees2DMS(value,type):
-    """
-        Converts a Decimal Degree Value into
-        Degrees Minute Seconds Notation.
-        
-        Pass value as double
-        type = {Latitude or Longitude} as string
-        
-        returns a string as D:M:S:Direction
-        created by: anothergisblog.blogspot.com 
-    """
+    
+    'Converts a Decimal Degree Value into Degrees Minute Seconds Notation. Pass value as double type = {Latitude or Longitude} as string returns a string as D:M:S:Direction created by: anothergisblog.blogspot.com' 
+
     degrees = int(value)
     submin = abs( (value - int(value) ) * 60)
     direction = ""
@@ -273,6 +265,7 @@ def _decimalDegrees2DMS(value,type):
 
 
 def _weighcalculator_prob(pr):
+    'calculate the picks weights'
     weight = 4
     if pr > 0.6:
         weight = 0
@@ -289,7 +282,8 @@ def _weighcalculator_prob(pr):
 
 
 
-def _date_convertor(r):  
+def _date_convertor(r): 
+    'convert datatime form string'
     if r and len(r)>5:
         mls = r.split('.')
         if len(mls) == 1:
@@ -301,7 +295,7 @@ def _date_convertor(r):
 
 
 def _doubleChecking(station_list, detections, preprocessed_dir, moving_window, thr_on=3.7, thr_of=0.5):
-
+    'this function perform traditional detection (STA/LTA) and picker (AIC) to double check for events on the remaining stations when an event has been detected on more than two stations'
     for stt in station_list:
         sttt = stt.split('_')[0]
       #  print(sttt)
